@@ -20,7 +20,7 @@ from glob import glob
 from kook.utils import read_file, write_file
 
 package   = prop('package', 'Oktest')
-release   = prop('release', '0.13.0')
+release   = prop('release', '0.14.0')
 copyright = prop('copyright', "copyright(c) 2010-2014 kuwata-lab.com all rights reserved")
 license   = "MIT License"
 python    = prop('python', sys.executable)
@@ -64,7 +64,7 @@ def _with_backup(filepath):
 
 TEST_NAMES = ('tracer', 'spec', 'testdeco', 'fixture',
               'doc', 'assertions', 'dummy', 'runner', 'context', 'reporter',
-              'util', 'skip', 'todo', 'resp', 'mainapp', 'web',)
+              'util', 'skip', 'todo', 'resp', 'mainapp', 'web', 'validator',)
 test_names = [ os.path.basename(x).replace('_test.py', '')
                    for x in glob("test/*_test.py") ]
 assert set(TEST_NAMES) == set(test_names)
